"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const http = require("http");
const path = require("path");
const url = require("url");
const chokidar = require("chokidar");
const portfinder = require("portfinder");
const generator_1 = require("../generator");
const getPage_1 = require("../repository/getPage");
const reloadScript_1 = require("./reloadScript");
const wsServer_1 = require("./wsServer");
const start = async (dirname, opts) => {
    const socketPort = await portfinder.getPortPromise();
    const initialSource = await getPage_1.getData(dirname, opts);
    let socket;
    let gPages = await generator_1.generateStatic(initialSource, opts);
    const watcher = chokidar.watch(dirname, {
        ignoreInitial: true,
    });
    wsServer_1.makeWebSocketServer(socketPort, (res) => {
        socket = res;
    });
    const update = async (updateParams) => {
        if (!socket) {
            return;
        }
        const updatedSource = await getPage_1.getData(dirname, { ...opts, watcher: updateParams });
        gPages = await generator_1.generateStatic(updatedSource, opts);
        socket.send(JSON.stringify({ reload: true }));
    };
    watcher.on("change", async (filename) => {
        const base = path.basename(filename);
        const ext = path.extname(base);
        if (!/\.(js|css|jsx|md|mdx|json)$/.test(ext)) {
            return;
        }
        await update({ filename });
    });
    const app = http.createServer((req, res) => {
        if (!req.url) {
            return;
        }
        const { pathname } = url.parse(req.url);
        if (!pathname) {
            return;
        }
        const filePath = path.join(dirname, pathname);
        if (fs.existsSync(filePath) && fs.statSync(filePath).isFile()) {
            fs.createReadStream(filePath).pipe(res);
            return;
        }
        const name = pathname === "/" ? "index" : pathname.replace(/^\//, "").replace(/\/$/, "");
        const renderStaticPage = gPages.find((targetPage) => targetPage.name === name);
        if (!renderStaticPage) {
            res.write("page not found: " + pathname);
            res.end();
            return;
        }
        res.write(renderStaticPage.html);
        res.write(reloadScript_1.reloadScript(socketPort));
        res.end();
    });
    try {
        const server = await app.listen(socketPort + 2);
        return server;
    }
    catch (err) {
        console.error(err);
        throw err;
    }
};
exports.server = start;
