"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const normalizer_1 = require("./normalizer");
const isIncludes = (params, searchElement) => {
    const hitParams = params.filter(param => param.isLocal === searchElement.isLocal && param.href === searchElement.href);
    hitParams.forEach(element => {
        console.error(`[Duplicated Error]: Scope: ${element.isLocal ? "local" : "global"}, src: ${element.href}`);
    });
    return hitParams.length > 0;
};
const getMakeTag = (dryParameter = []) => (attributes, isLocal) => {
    if (typeof attributes === "string") {
        const normalizedSource1 = normalizer_1.normalizerSourcePath(attributes, isLocal);
        if (isIncludes(dryParameter, { href: attributes, isLocal })) {
            return;
        }
        else {
            dryParameter.push({
                href: attributes,
                isLocal,
            });
        }
        return React.createElement("link", { href: normalizedSource1, key: normalizedSource1, rel: "stylesheet" });
    }
    if (!attributes.href) {
        return;
    }
    const normalizedSource2 = normalizer_1.normalizerSourcePath(attributes.href, isLocal);
    if (isIncludes(dryParameter, { href: normalizedSource2, isLocal })) {
        return;
    }
    else {
        dryParameter.push({
            href: normalizedSource2,
            isLocal,
        });
    }
    return React.createElement("link", Object.assign({}, { ...attributes, href: normalizedSource2 }, { key: normalizedSource2 }));
};
exports.generateLinkElements = ({ localLinks, globalLinks }) => {
    const elements = [];
    const makeTag = getMakeTag();
    if (globalLinks) {
        globalLinks.forEach(attribute => {
            const tagElement = makeTag(attribute, false);
            if (tagElement) {
                elements.push(tagElement);
            }
        });
    }
    if (localLinks) {
        localLinks.forEach(attribute => {
            const tagElement = makeTag(attribute, true);
            if (tagElement) {
                elements.push(tagElement);
            }
        });
    }
    return elements;
};
