"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const normalizer_1 = require("./normalizer");
const isIncludes = (params, searchElement) => {
    const hitParams = params.filter(param => param.isLocal === searchElement.isLocal && param.src === searchElement.src);
    hitParams.forEach(element => {
        console.error(`[Duplicated Error]: Scope: ${element.isLocal ? "local" : "global"}, src: ${element.src}`);
    });
    return hitParams.length > 0;
};
const getMakeScriptTag = (dryParameter = []) => (attributes, isLocal) => {
    if (typeof attributes === "string") {
        const normalizedSource1 = normalizer_1.normalizerSourcePath(attributes, isLocal);
        if (isIncludes(dryParameter, { src: attributes, isLocal })) {
            return;
        }
        else {
            dryParameter.push({
                src: attributes,
                isLocal,
            });
        }
        return React.createElement("script", { src: normalizedSource1, key: normalizedSource1 });
    }
    if (!attributes.src) {
        return;
    }
    const normalizedSource2 = normalizer_1.normalizerSourcePath(attributes.src, isLocal);
    if (isIncludes(dryParameter, { src: normalizedSource2, isLocal })) {
        return;
    }
    else {
        dryParameter.push({
            src: normalizedSource2,
            isLocal,
        });
    }
    return React.createElement("script", Object.assign({}, { ...attributes, src: normalizedSource2 }, { key: normalizedSource2 }));
};
exports.generateScriptElements = ({ localScripts, globalScripts }) => {
    const elements = [];
    const makeScriptTag = getMakeScriptTag();
    if (globalScripts) {
        globalScripts.forEach(attribute => {
            const tagElement = makeScriptTag(attribute, false);
            if (tagElement) {
                elements.push(tagElement);
            }
        });
    }
    if (localScripts) {
        localScripts.forEach(attribute => {
            const tagElement = makeScriptTag(attribute, true);
            if (tagElement) {
                elements.push(tagElement);
            }
        });
    }
    return elements;
};
